=== modified file 'NEWS'
--- NEWS	2007-09-03 23:19:00 +0000
+++ NEWS	2007-09-04 01:20:26 +0000
@@ -154,6 +154,11 @@
    * If versioned files match a given ignore pattern, a warning is now
      given. (Daniel Watkins, #48623)
 
+   * ``bzr status`` now has -S as a short name for --short and -V as a
+     short name for --versioned. These have been added to assist users
+     migrating from Subversion: ``bzr status -SV`` is now like
+     ``svn status -q``.  (Daniel Watkins, #115990)
+
   API BREAKS:
 
    * ``Branch.append_revision`` is removed altogether; please use 

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2007-09-03 08:23:34 +0000
+++ bzrlib/builtins.py	2007-09-04 01:20:26 +0000
@@ -152,8 +152,9 @@
     To see ignored files use 'bzr ignored'.  For details on the
     changes to file texts, use 'bzr diff'.
     
-    --short gives a status flags for each item, similar to the SVN's status
-    command.
+    Note that --short or -S gives status flags for each item, similar
+    to Subversion's status command. To get output similar to svn -q,
+    use bzr -SV.
 
     If no arguments are specified, the status of the entire working
     directory is shown.  Otherwise, only the status of the specified
@@ -168,8 +169,11 @@
     
     takes_args = ['file*']
     takes_options = ['show-ids', 'revision', 'change',
-                     Option('short', help='Give short SVN-style status lines.'),
-                     Option('versioned', help='Only show versioned files.')]
+                     Option('short', help='Use short status indicators.',
+                            short_name='S'),
+                     Option('versioned', help='Only show versioned files.',
+                            short_name='V')
+                     ]
     aliases = ['st', 'stat']
 
     encoding_type = 'replace'

=== modified file 'bzrlib/tests/blackbox/test_status.py'
--- bzrlib/tests/blackbox/test_status.py	2007-09-01 16:04:44 +0000
+++ bzrlib/tests/blackbox/test_status.py	2007-09-04 01:20:26 +0000
@@ -371,6 +371,28 @@
         result2 = self.run_bzr("status --versioned -r 0..")[0]
         self.assertEquals(result2, result)
 
+    def test_status_SV(self):
+        tree = self.make_branch_and_tree('.')
+
+        self.build_tree(['hello.txt'])
+        result = self.run_bzr("status -SV")[0]
+        self.assertNotContainsRe(result, "hello.txt")
+
+        tree.add("hello.txt")
+        result = self.run_bzr("status -SV")[0]
+        self.assertContainsRe(result, "[+]N  hello.txt\n")
+
+        tree.commit(message="added")
+        result = self.run_bzr("status -SV -r 0..1")[0]
+        self.assertContainsRe(result, "[+]N  hello.txt\n")
+
+        self.build_tree(['world.txt'])
+        result = self.run_bzr("status -SV -r 0")[0]
+        self.assertContainsRe(result, "[+]N  hello.txt\n")
+
+        result2 = self.run_bzr("status -SV -r 0..")[0]
+        self.assertEquals(result2, result)
+
     def assertStatusContains(self, pattern):
         """Run status, and assert it contains the given pattern"""
         result = self.run_bzr("status --short")[0]

